package gov.usgs.earthquake.nshmp.www;

import java.nio.file.Path;
import java.util.ArrayList;

import org.eclipse.jgit.api.Git;

import com.google.common.io.Resources;

import gov.usgs.earthquake.nshmp.internal.AppVersion;
import gov.usgs.earthquake.nshmp.internal.LibVersion;

public class HazVersion implements AppVersion {

  public static VersionInfo[] appVersions(Path modelPath) {
    var versions = new ArrayList<VersionInfo>();
    versions.add(new HazVersion().getVersionInfo());
    versions.add(new LibVersion().getVersionInfo());
    versions.add(new WsUtilsVersion().getVersionInfo());

    var nshmVersion = getNshmVersion(modelPath);

    if (nshmVersion != null) {
      versions.add(nshmVersion);
    }

    return versions.toArray(new VersionInfo[0]);
  }

  /**
   * Returns the version info from resources file.
   */
  public VersionInfo getVersionInfo() {
    var resource = Resources.getResource("version/nshmp-haz-version.json");
    return AppVersion.versionInfo(resource);
  }

  /**
   * Returns the version info of a repository.
   *
   * If the model path is not a git repository, returns null.
   *
   * @param modelPath The path to the model
   */
  private static VersionInfo getNshmVersion(Path modelPath) {
    try {
      var git = Git.open(modelPath.toFile());
      var repo = git.getRepository();
      var url = repo
          .getConfig()
          .getString("remote", "origin", "url")
          .split(".git")[0];
      var slash = url.split("/");
      var projectName = slash[slash.length - 1];

      return VersionInfo.builder()
          .projectName(projectName)
          .url(url)
          .version(git.describe().call())
          .gitHash(repo.getRefDatabase().findRef("HEAD").getObjectId().name())
          .build();
    } catch (Exception e) {
      return null;
    }
  }
}
