package gov.usgs.earthquake.nshmp.www.source;

import java.util.Optional;
import java.util.Set;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import gov.usgs.earthquake.nshmp.model.HazardModel;
import gov.usgs.earthquake.nshmp.model.Models;
import gov.usgs.earthquake.nshmp.model.SourceType;
import gov.usgs.earthquake.nshmp.model.TectonicSetting;
import gov.usgs.earthquake.nshmp.www.HazVersion;
import gov.usgs.earthquake.nshmp.www.ResponseBody;
import gov.usgs.earthquake.nshmp.www.ResponseMetadata;
import gov.usgs.earthquake.nshmp.www.ServletUtil;
import gov.usgs.earthquake.nshmp.www.source.SourceService.SourceModel;

import io.micronaut.http.HttpRequest;
import io.micronaut.http.HttpResponse;
import jakarta.inject.Singleton;

/**
 * Source model MFD handler {@link MfdsController}
 *
 * @author U.S. Geological Survey
 */
@Singleton
public class MfdsService {

  static final String NAME = "Model MFDs";
  static final Logger LOG = LoggerFactory.getLogger(LogicTreesService.class);

  public static HttpResponse<String> getMetadata(HttpRequest<?> request) {
    var url = request.getUri().toString();
    var metadata = new Metadata(ServletUtil.model());
    var response = ResponseBody.usage()
        .name(NAME)
        .url(url)
        .metadata(new ResponseMetadata(HazVersion.appVersions(ServletUtil.model().root())))
        .request(url)
        .response(metadata)
        .build();
    return HttpResponse.ok(ServletUtil.GSON2.toJson(response));
  }

  public static HttpResponse<String> getMfdGroup(
      HttpRequest<?> request,
      TectonicSetting setting,
      Optional<SourceType> type) {

    var url = request.getUri().toString();
    var mfd = Models.mfd(ServletUtil.model(), setting, type);
    var requestData = new RequestData(setting, type.orElse(null));
    var response = ResponseBody.success()
        .name(NAME)
        .url(url)
        .metadata(new ResponseMetadata(HazVersion.appVersions(ServletUtil.model().root())))
        .request(requestData)
        .response(mfd)
        .build();
    return HttpResponse.ok(ServletUtil.GSON2.toJson(response));
  }

  static class Metadata {
    final SourceModel model;
    final Set<TectonicSetting> settings;
    final Set<SourceType> types;

    Metadata(HazardModel model) {
      this.model = new SourceModel(model);
      this.settings = model.settings();
      this.types = model.types();
    }

    public SourceModel getModel() {
      return model;
    }

    public Set<TectonicSetting> getSettings() {
      return settings;
    }

    public Set<SourceType> getTypes() {
      return types;
    }
  }

  static class RequestData {
    final TectonicSetting setting;
    final SourceType type;

    RequestData(TectonicSetting setting, SourceType type) {
      this.setting = setting;
      this.type = type;
    }

    public TectonicSetting getSetting() {
      return setting;
    }

    public SourceType getType() {
      return type;
    }
  }

}
