package gov.usgs.earthquake.nshmp.www.hazard;

import java.util.LinkedHashMap;
import java.util.Map;
import java.util.Map.Entry;
import java.util.Set;
import java.util.concurrent.ExecutionException;
import java.util.stream.Collectors;

import gov.usgs.earthquake.nshmp.NamedLocation;
import gov.usgs.earthquake.nshmp.calc.Hazard;
import gov.usgs.earthquake.nshmp.data.XySequence;
import gov.usgs.earthquake.nshmp.gmm.Imt;
import gov.usgs.earthquake.nshmp.www.hazard.HazardService.Request;

import io.micronaut.http.HttpRequest;

public class HazardServiceUtils {

  public static Map<String, XySequence> generateActual(
      NamedLocation loc,
      Set<Imt> imts)
      throws InterruptedException, ExecutionException {
    Request request = new Request(
        HttpRequest.GET(""),
        loc.location().longitude,
        loc.location().latitude,
        760,
        imts,
        false,
        false);

    Hazard hazard = HazardService.calcHazard(request);

    Map<String, XySequence> xyMap = hazard.curves().entrySet().stream()
        .collect(Collectors.toMap(
            e -> e.getKey().name(),
            Entry::getValue,
            (o1, o2) -> o1,
            LinkedHashMap::new)); // preserve IMT enum order

    return xyMap;
  }
}
