####
# Run hazard web services.
#
# Pull Docker Image:
#   - Production (stable): docker pull usgs/nshmp-haz-ws:production-latest
#   - Staging (latest, main branch of repo): docker pull usgs/nshmp-haz-ws:staging-latest
#   - Development (developer forks): docker pull usgs/nshmp-haz-ws:development-latest
#
# Build locally:
#   docker build
#       -f ws.Dockerfile
#       -t nshmp-haz-ws .
#
# Run locally:
#   docker run -p 8080:8080
#       -v "path/to/model:/app/model"
#       nshmp-haz-ws
####

ARG BUILD_IMAGE=code.usgs.gov:5001/devops/images/usgs/java:11
ARG FROM_IMAGE=code.usgs.gov:5001/devops/images/usgs/java:11

####
# Builder image: Build jar file.
####
FROM ${BUILD_IMAGE} as builder

ARG builder_workdir

# For GitLab CI/CD
ARG CI_PROJECT_URL=null
ARG CI_COMMIT_BRANCH=null

WORKDIR /app

COPY . .

USER root

RUN ./gradlew assemble

####
# Application image: Run jar file.
####
FROM ${FROM_IMAGE}

LABEL maintainer="Peter Powers <pmpowers@usgs.gov>, Brandon Clayton <bclayton@usgs.gov>"

ENV CONTEXT_PATH="/"
ENV JAVA_OPTS="-Xms2g -Xmx8g"
ENV MODELS_DIRECTORY="/app/model"

WORKDIR /app

USER root

RUN mkdir /asset-output  \
    && chown -R usgs-user:usgs-user /app \
    && chown -R usgs-user:usgs-user /asset-output

USER usgs-user

COPY --from=builder --chown=usgs-user:usgs-user /app/build/libs/nshmp-haz.jar .
COPY --from=builder --chown=usgs-user:usgs-user /app/nshms.yml .

VOLUME [ "${MODELS_DIRECTORY}" ]

EXPOSE 8080

ENTRYPOINT java \
    ${JAVA_OPTS} \
    -jar \
    nshmp-haz.jar \
    "-Dmicronaut.server.context-path=${CONTEXT_PATH}" \
    --MODEL="${MODELS_DIRECTORY}";
